      subroutine write_params(nids_tot, fids, ids, ts, ps, os, xs, ys,
     $     mags, pft_ccs, prj_ccs, cmp_ccs, param_fnames, img_fnames,
     $     mag_norm)

C     Write out new particle parameter files. Also normalize the mag
C     scale factors if mag_norm == 1

      implicit none

      character(len=256), intent(in) :: param_fnames(999)
      character(len=256), intent(in) :: img_fnames(999)
      integer, intent(in) :: nids_tot, mag_norm
      integer, intent(in) :: fids(nids_tot), ids(nids_tot)
      real, intent(in)    :: ts(nids_tot), ps(nids_tot), os(nids_tot)
      real, intent(in)    :: xs(nids_tot), ys(nids_tot)
      real, intent(in)    :: pft_ccs(nids_tot), prj_ccs(nids_tot)
      real, intent(in)    :: cmp_ccs(nids_tot)
      real, intent(inout) :: mags(nids_tot)
      
      common/ctf_com/pixsiz, units, volts, amp_fac, focus_maj, 
     $     focus_min, ang_maj, cs_coeff

      integer units(999)
      real    pixsiz(999), volts(999), amp_fac(999), cs_coeff(999)
      real    focus_maj(999), focus_min(999), ang_maj(999)

      integer file, file_last, id, mag_factor
      logical fileopen
      character(len=256) img_filename, new_fname


C     Normalize mag scale factors if mag_norm == 1. Note - using Fortran
C     90 intrinsic function sum() to calcualte mag_factor and array
C     syntax to scale elements of array mags

      if(mag_norm == 1) then
         mag_factor = sum(mags)/real(nids_tot)
         mags = mags / mag_factor
         write(*,*) 'Mean of mag scale factors (= ', mag_factor,
     $        ') renormalized to 1'
      endif

C     Write out new particle parameter files
      file_last = 0
      do id = 1, nids_tot
         file = fids(id)

C     Open new file and write header information
         if(file .ne. file_last) then
            call increment_fname(param_fnames(file), new_fname)
            inquire(unit=19, opened=fileopen)
            if(fileopen) close(19)
            open(unit=19, file=new_fname)
            write(19,'(A)') ' '//trim(adjustl(img_fnames(file)))
            write(19,1010) pixsiz(file), units(file), volts(file),
     $           amp_fac(file),focus_maj(file), focus_min(file),
     $           ang_maj(file), cs_coeff(file)
            file_last = file
         endif
         
C     Print particle image data
         write(19,1020) ids(id), ts(id), ps(id), os(id), xs(id), ys(id),
     $        mags(id), pft_ccs(id), prj_ccs(id), cmp_ccs(id)
      enddo
      close (unit=19)
      
 1010 format (1x,f8.4,',',i2,',',f10.1,',',3(f10.4,','),f10.4,',',f8.2)
 1020 format (1x,i6,',',4(f8.3,','),f7.3,',',3(f6.3,','),f6.3)
      
      return
      end subroutine write_params
